@@ -2,9 +2,10 @@
 from domainpy.utils.constructable import Constructable
 from domainpy.utils.immutable import Immutable
 from domainpy.utils.dictable import Dictable
+from domainpy.utils.traceable import Traceable
 
 
-class DomainEvent(Constructable, Immutable, Dictable):
+class DomainEvent(Constructable, Immutable, Dictable, Traceable):
     
     def __init__(self, *args, **kwargs):
         self.__dict__.update({
